@@ -404,17 +404,17 @@ class TempWidget:
 
 
 class PumpConfigWidget:
+
     def __init__(self, device, main_gui):
-        layout = Layout(display='flex', width='180px')
+        layout = Layout(display='flex', width='170px')
         style = {'description_width': '90px'}
         self.device = device
         self.refresh_button = widgets.Button(icon="fa-sync-alt", layout=Layout(width="40px"))
         self.refresh_button.on_click(self.handle_refresh_button)
-        self.active_pumps = HBox([widgets.Checkbox(description="MAIN MEDIUM - pump 1", style=style, layout=layout),
-                                  widgets.Checkbox(description="MEDIUM 2 - pump 2", style=style, layout=layout),
-                                  widgets.Checkbox(description="MEDIUM 3 - pump 3", style=style, layout=layout),
-                                  widgets.Checkbox(description="WASTE - pump 4", style=style, layout=layout,
-                                                   disabled=True)])
+        self.active_pumps = HBox([widgets.Checkbox(description="MAIN MEDIUM - pump 1", style=style, layout=layout, indent=False),
+                                  widgets.Checkbox(description="MEDIUM 2 - pump 2", style=style, layout=layout, indent=False),
+                                  widgets.Checkbox(description="MEDIUM 3 - pump 3", style=style, layout=layout, indent=False),
+                                  widgets.Checkbox(description="WASTE - pump 4", style=style, layout=layout, indent=False, disabled=True)])
         stock_volume = [
             widgets.FloatText(description="volume", description_tooltip="Volume in stock bottle [mL]", style=style,
                               layout=layout),
@@ -424,6 +424,7 @@ class PumpConfigWidget:
                               layout=layout),
             widgets.FloatText(description="volume", description_tooltip="Free volume in waste bottle [mL]", style=style,
                               layout=layout)]
+
         self.stock_volume = HBox(stock_volume)
         stock_concentration = [
             widgets.FloatText(description="concentration", description_tooltip="", style=style, layout=layout),
@@ -435,6 +436,16 @@ class PumpConfigWidget:
                               disabled=True)]
         self.stock_concentration = HBox(stock_concentration)
         self.handle_refresh_button(0)
+
+        self.stock_volume_widget_pump = {self.stock_volume.children[0]: self.device.pump1,
+                                         self.stock_volume.children[1]: self.device.pump2,
+                                         self.stock_volume.children[2]: self.device.pump3,
+                                         self.stock_volume.children[3]: self.device.pump4}
+        self.stock_conc_widget_pump = {self.stock_concentration.children[0]: self.device.pump1,
+                                       self.stock_concentration.children[1]: self.device.pump2,
+                                       self.stock_concentration.children[2]: self.device.pump3,
+                                       self.stock_concentration.children[3]: self.device.pump4}
+
         if self.device.directory is None:
             for p in range(4):
                 self.stock_volume.children[p].disabled = True
@@ -445,9 +456,9 @@ class PumpConfigWidget:
                 print("Device directory not defined")
         else:
             for c in self.stock_volume.children:
-                c.observe(self.update_stock_volume)
+                c.observe(self.update_stock_volume, names=["value"])
             for c in self.stock_concentration.children:
-                c.observe(self.update_stock_concentration)
+                c.observe(self.update_stock_concentration, names=["value"])
 
             for c in self.active_pumps.children:
                 c.observe(self.handle_active_pumps_checkbox)
@@ -456,16 +467,19 @@ class PumpConfigWidget:
             self.widget = VBox([self.refresh_button, self.active_pumps, self.stock_volume, self.stock_concentration])
 
     def update_stock_volume(self, change):
-        self.device.pump1.stock_volume = self.stock_volume.children[0].value
-        self.device.pump2.stock_volume = self.stock_volume.children[1].value
-        self.device.pump3.stock_volume = self.stock_volume.children[2].value
-        self.device.pump4.stock_volume = self.stock_volume.children[3].value
+        self.stock_volume_widget_pump[change.owner].stock_volume = change.new
+        # self.device.pump1.stock_volume = self.stock_volume.children[0].value
+        # self.device.pump2.stock_volume = self.stock_volume.children[1].value
+        # self.device.pump3.stock_volume = self.stock_volume.children[2].value
+        # self.device.pump4.stock_volume = self.stock_volume.children[3].value
 
     def update_stock_concentration(self, change):
-        self.device.pump1.stock_concentration = self.stock_concentration.children[0].value
-        self.device.pump2.stock_concentration = self.stock_concentration.children[1].value
-        self.device.pump3.stock_concentration = self.stock_concentration.children[2].value
-        self.device.pump4.stock_concentration = self.stock_concentration.children[3].value
+        self.stock_conc_widget_pump[change.owner].stock_concentration = change.new
+
+        # self.device.pump1.stock_concentration = self.stock_concentration.children[0].value
+        # self.device.pump2.stock_concentration = self.stock_concentration.children[1].value
+        # self.device.pump3.stock_concentration = self.stock_concentration.children[2].value
+        # self.device.pump4.stock_concentration = self.stock_concentration.children[3].value
 
     def update_active_pumps_checkbox(self):
         for p in [1, 2, 3, 4]:
